/* LOCKVC Version 3.0 (c) 1994, 1995, 1997 by Matthias Straub */
/* shadow-password option added by Ed Beaumont */
/* integer math derived from a patch by Jeff Epler */
/* this file was released under GPL */
/* see COPYING for details */

#include <stdio.h>
#include <time.h>
#include <string.h>

#include "lockvc.h"

#define ANZSAVER 4

void mod_choose(int argc, char **argv, int *saver)
{       

    *saver=time(NULL)%ANZSAVER;
    if(argc>1)
    {
	if(!strcmp(argv[1],"stars"))*saver=0;
	if(!strcmp(argv[1],"morph"))*saver=1;
	if(!strcmp(argv[1],"fire"))*saver=2;
	if(!strcmp(argv[1],"fudge"))*saver=3;
	if(argv[1][0]=='-')
	{
	    printf("usage:       lockvc stars [<number> <stride>]\n"
	    "             lockvc morph [<number>]\n"
	    "             lockvc fudge\n"
	    "             lockvc fire\n");
	    printf("---                                                                ---\n");
	    
	    exit(0);
	}                       
	
    }       
} 
        
void mod_start(int argc, char **argv,int *saver)
{
	switch (*saver)
	{
	case 0:
	starfield(argc,argv); 
	case 1:
	morphdots(argc,argv);
	case 2:
	feuer();
	case 3:
	fudge(argc,argv);
	}
}
